@@ -331,8 +331,6 @@ void                fm_directory_view_move_copy_items                  (const GL
 									int               x,
 									int               y,
 									FMDirectoryView  *view);
-gboolean            fm_directory_link_type_in_selection                (FMDirectoryView  *view,
-									NautilusLinkType  link_type);
 
 /* Wrappers for signal emitters. These are normally called 
  * only by FMDirectoryView itself. They have corresponding signals
@@ -376,5 +374,14 @@ void                fm_directory_view_new_file                         (FMDirect
 									NautilusFile     *source);
 void                fm_directory_view_ignore_hidden_file_preferences   (FMDirectoryView  *view);
 void                fm_directory_view_init_view_iface                  (NautilusViewIface *iface);
-
+void                fm_directory_view_handle_url_drop                  (FMDirectoryView  *view,
+									const char       *encoded_url,
+									GdkDragAction     action,
+									int               x,
+									int               y);
+void                fm_directory_view_handle_uri_list_drop             (FMDirectoryView  *view,
+									const char       *item_uris,
+									GdkDragAction     action,
+									int               x,
+									int               y);
 #endif /* FM_DIRECTORY_VIEW_H */
